sqlobject.tests.test_delete module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_delete module

class `sqlobject.tests.test_delete.` `NoCache`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = no_cache
  property `name`
  `q` = no_cache
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_delete.NoCache`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'no_cache'

class `sqlobject.tests.test_delete.` `Service`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addServiceGroup`(obj)
  property `groups`
  `j` = service
  `q` = service
  `removeServiceGroup`(obj)
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.RelatedJoin object>]
    `joins` = [<sqlobject.joins.SORelatedJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_delete.Service`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'service'

class `sqlobject.tests.test_delete.` `ServiceGroup`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addService`(obj)
  `j` = service_group
  `q` = service_group
  `removeService`(obj)
  property `services`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.RelatedJoin object>]
    `joins` = [<sqlobject.joins.SORelatedJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_delete.ServiceGroup`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'service_group'

`sqlobject.tests.test_delete.` `testDeleteBy`()

`sqlobject.tests.test_delete.` `testDeleteMany`()

`sqlobject.tests.test_delete.` `testDeleteRelatedJoins`()

`sqlobject.tests.test_delete.` `testDestroySelf`()

`sqlobject.tests.test_delete.` `testSelect`()